Site frequencies
================

.. automodule:: anhima.sf
.. autofunction:: site_frequency_spectrum
.. autofunction:: site_frequency_spectrum_scaled
.. autofunction:: site_frequency_spectrum_folded
.. autofunction:: site_frequency_spectrum_folded_scaled
.. autofunction:: plot_site_frequency_spectrum








